imodels.rule_set.slipper API documentation

# Module `imodels.rule_set.slipper`

Expand source code

    from imodels.rule_set.boosted_rules import BoostedRulesClassifier
    from imodels.rule_set.slipper_util import SlipperBaseEstimator

    class SlipperClassifier(BoostedRulesClassifier):
        def __init__(self, n_estimators=10):
            '''
            An estimator that supports building rules as described in
            A Simple, Fast, and Effective Rule Learner (1999).
            Parameters
            ----------
            n_estimators
            '''
            super().__init__(n_estimators, SlipperBaseEstimator)

## Classes

`class SlipperClassifier (n_estimators=10)`

  An easy-interpretable classifier optimizing simple logical rules. Currently limited to only binary classification.

  ## Params

  estimator: object with fit and predict methods Defaults to DecisionTreeClassifier with AdaBoost. For SLIPPER, should pass estimator=imodels.SlipperBaseEstimator

  An estimator that supports building rules as described in A Simple, Fast, and Effective Rule Learner (1999). Parameters

  `n_estimators`
  Expand source code

      class SlipperClassifier(BoostedRulesClassifier):
          def __init__(self, n_estimators=10):
              '''
              An estimator that supports building rules as described in
              A Simple, Fast, and Effective Rule Learner (1999).
              Parameters
              ----------
              n_estimators
              '''
              super().__init__(n_estimators, SlipperBaseEstimator)

  ### Ancestors

  - BoostedRulesClassifier
  - RuleSet
  - sklearn.base.BaseEstimator
  - sklearn.base.MetaEstimatorMixin
  - sklearn.base.ClassifierMixin

  ### Inherited members

  - `BoostedRulesClassifier`:
    - `fit`
    - `predict`
    - `predict_proba`